# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLabelMapPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkLabelImageToStatisticsLabelMapFilterPython
else:
    import _itkLabelImageToStatisticsLabelMapFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.ITKLabelMapBasePython
import itk.itkImageSourceCommonPython
import itk.itkStatisticsLabelObjectPython
import itk.itkShapeLabelObjectPython
import itk.itkAffineTransformPython
import itk.itkMatrixOffsetTransformBasePython
import itk.itkVariableLengthVectorPython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.itkArray2DPython
import itk.itkTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkLabelObjectPython
import itk.itkLabelObjectLinePython
import itk.itkHistogramPython
import itk.itkSamplePython
import itk.itkImageSourcePython
import itk.itkVectorImagePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterCommonPython

def itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_New():
    return itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2.New()

class itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2(itk.ITKLabelMapBasePython.itkImageToImageFilterIUC2LM2):
    r"""Proxy of C++ itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_Pointer"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_Pointer"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_Clone(self)
    InputEqualityComparableCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned long"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_GetBackgroundValue(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_ComputePerimeterOff(self)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF2"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_SetInput2(self, input)

    def SetComputeHistogram(self, _arg):
        r"""
        SetComputeHistogram(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_SetComputeHistogram(self, _arg)

    def GetComputeHistogram(self):
        r"""GetComputeHistogram(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_GetComputeHistogram(self)

    def ComputeHistogramOn(self):
        r"""ComputeHistogramOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_ComputeHistogramOn(self)

    def ComputeHistogramOff(self):
        r"""ComputeHistogramOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_ComputeHistogramOff(self)

    def SetNumberOfBins(self, _arg):
        r"""
        SetNumberOfBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_SetNumberOfBins(self, _arg)

    def GetNumberOfBins(self):
        r"""GetNumberOfBins(self) -> unsigned int const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_GetNumberOfBins(self)
    __swig_destroy__ = _itkLabelImageToStatisticsLabelMapFilterPython.delete_itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2

        Create a new object of the class itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2 in _itkLabelImageToStatisticsLabelMapFilterPython:
_itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2_swigregister(itkLabelImageToStatisticsLabelMapFilterIUC2IF2LM2)

def itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_New():
    return itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2.New()

class itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2(itk.ITKLabelMapBasePython.itkImageToImageFilterIUC2LM2):
    r"""Proxy of C++ itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_Pointer"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_Pointer"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_Clone(self)
    InputEqualityComparableCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned long"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetBackgroundValue(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_ComputePerimeterOff(self)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageSS2"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetInput2(self, input)

    def SetComputeHistogram(self, _arg):
        r"""
        SetComputeHistogram(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetComputeHistogram(self, _arg)

    def GetComputeHistogram(self):
        r"""GetComputeHistogram(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetComputeHistogram(self)

    def ComputeHistogramOn(self):
        r"""ComputeHistogramOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_ComputeHistogramOn(self)

    def ComputeHistogramOff(self):
        r"""ComputeHistogramOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_ComputeHistogramOff(self)

    def SetNumberOfBins(self, _arg):
        r"""
        SetNumberOfBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_SetNumberOfBins(self, _arg)

    def GetNumberOfBins(self):
        r"""GetNumberOfBins(self) -> unsigned int const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_GetNumberOfBins(self)
    __swig_destroy__ = _itkLabelImageToStatisticsLabelMapFilterPython.delete_itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2

        Create a new object of the class itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2 in _itkLabelImageToStatisticsLabelMapFilterPython:
_itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2_swigregister(itkLabelImageToStatisticsLabelMapFilterIUC2ISS2LM2)

def itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_New():
    return itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2.New()

class itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2(itk.ITKLabelMapBasePython.itkImageToImageFilterIUC2LM2):
    r"""Proxy of C++ itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_Pointer"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_Pointer"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_Clone(self)
    InputEqualityComparableCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned long"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetBackgroundValue(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_ComputePerimeterOff(self)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageUC2"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetInput2(self, input)

    def SetComputeHistogram(self, _arg):
        r"""
        SetComputeHistogram(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetComputeHistogram(self, _arg)

    def GetComputeHistogram(self):
        r"""GetComputeHistogram(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetComputeHistogram(self)

    def ComputeHistogramOn(self):
        r"""ComputeHistogramOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_ComputeHistogramOn(self)

    def ComputeHistogramOff(self):
        r"""ComputeHistogramOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_ComputeHistogramOff(self)

    def SetNumberOfBins(self, _arg):
        r"""
        SetNumberOfBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_SetNumberOfBins(self, _arg)

    def GetNumberOfBins(self):
        r"""GetNumberOfBins(self) -> unsigned int const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_GetNumberOfBins(self)
    __swig_destroy__ = _itkLabelImageToStatisticsLabelMapFilterPython.delete_itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2

        Create a new object of the class itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2 in _itkLabelImageToStatisticsLabelMapFilterPython:
_itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2_swigregister(itkLabelImageToStatisticsLabelMapFilterIUC2IUC2LM2)

def itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_New():
    return itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3.New()

class itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3(itk.ITKLabelMapBasePython.itkImageToImageFilterIUC3LM3):
    r"""Proxy of C++ itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_Pointer"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_Pointer"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_Clone(self)
    InputEqualityComparableCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned long"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_GetBackgroundValue(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_ComputePerimeterOff(self)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF3"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_SetInput2(self, input)

    def SetComputeHistogram(self, _arg):
        r"""
        SetComputeHistogram(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_SetComputeHistogram(self, _arg)

    def GetComputeHistogram(self):
        r"""GetComputeHistogram(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_GetComputeHistogram(self)

    def ComputeHistogramOn(self):
        r"""ComputeHistogramOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_ComputeHistogramOn(self)

    def ComputeHistogramOff(self):
        r"""ComputeHistogramOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_ComputeHistogramOff(self)

    def SetNumberOfBins(self, _arg):
        r"""
        SetNumberOfBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_SetNumberOfBins(self, _arg)

    def GetNumberOfBins(self):
        r"""GetNumberOfBins(self) -> unsigned int const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_GetNumberOfBins(self)
    __swig_destroy__ = _itkLabelImageToStatisticsLabelMapFilterPython.delete_itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3

        Create a new object of the class itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3 in _itkLabelImageToStatisticsLabelMapFilterPython:
_itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3_swigregister(itkLabelImageToStatisticsLabelMapFilterIUC3IF3LM3)

def itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_New():
    return itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3.New()

class itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3(itk.ITKLabelMapBasePython.itkImageToImageFilterIUC3LM3):
    r"""Proxy of C++ itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_Pointer"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_Pointer"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_Clone(self)
    InputEqualityComparableCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned long"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetBackgroundValue(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_ComputePerimeterOff(self)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageSS3"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetInput2(self, input)

    def SetComputeHistogram(self, _arg):
        r"""
        SetComputeHistogram(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetComputeHistogram(self, _arg)

    def GetComputeHistogram(self):
        r"""GetComputeHistogram(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetComputeHistogram(self)

    def ComputeHistogramOn(self):
        r"""ComputeHistogramOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_ComputeHistogramOn(self)

    def ComputeHistogramOff(self):
        r"""ComputeHistogramOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_ComputeHistogramOff(self)

    def SetNumberOfBins(self, _arg):
        r"""
        SetNumberOfBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_SetNumberOfBins(self, _arg)

    def GetNumberOfBins(self):
        r"""GetNumberOfBins(self) -> unsigned int const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_GetNumberOfBins(self)
    __swig_destroy__ = _itkLabelImageToStatisticsLabelMapFilterPython.delete_itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3

        Create a new object of the class itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3 in _itkLabelImageToStatisticsLabelMapFilterPython:
_itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3_swigregister(itkLabelImageToStatisticsLabelMapFilterIUC3ISS3LM3)

def itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_New():
    return itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3.New()

class itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3(itk.ITKLabelMapBasePython.itkImageToImageFilterIUC3LM3):
    r"""Proxy of C++ itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_Pointer"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_Pointer"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_Clone(self)
    InputEqualityComparableCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned long

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned long"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetBackgroundValue(self)

    def SetComputeFeretDiameter(self, _arg):
        r"""
        SetComputeFeretDiameter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetComputeFeretDiameter(self, _arg)

    def GetComputeFeretDiameter(self):
        r"""GetComputeFeretDiameter(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetComputeFeretDiameter(self)

    def ComputeFeretDiameterOn(self):
        r"""ComputeFeretDiameterOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_ComputeFeretDiameterOn(self)

    def ComputeFeretDiameterOff(self):
        r"""ComputeFeretDiameterOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_ComputeFeretDiameterOff(self)

    def SetComputePerimeter(self, _arg):
        r"""
        SetComputePerimeter(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetComputePerimeter(self, _arg)

    def GetComputePerimeter(self):
        r"""GetComputePerimeter(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetComputePerimeter(self)

    def ComputePerimeterOn(self):
        r"""ComputePerimeterOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_ComputePerimeterOn(self)

    def ComputePerimeterOff(self):
        r"""ComputePerimeterOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_ComputePerimeterOff(self)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageUC3"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetInput2(self, input)

    def SetComputeHistogram(self, _arg):
        r"""
        SetComputeHistogram(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetComputeHistogram(self, _arg)

    def GetComputeHistogram(self):
        r"""GetComputeHistogram(self) -> bool const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetComputeHistogram(self)

    def ComputeHistogramOn(self):
        r"""ComputeHistogramOn(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_ComputeHistogramOn(self)

    def ComputeHistogramOff(self):
        r"""ComputeHistogramOff(self)"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_ComputeHistogramOff(self)

    def SetNumberOfBins(self, _arg):
        r"""
        SetNumberOfBins(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_SetNumberOfBins(self, _arg)

    def GetNumberOfBins(self):
        r"""GetNumberOfBins(self) -> unsigned int const &"""
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_GetNumberOfBins(self)
    __swig_destroy__ = _itkLabelImageToStatisticsLabelMapFilterPython.delete_itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3

        Create a new object of the class itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3 in _itkLabelImageToStatisticsLabelMapFilterPython:
_itkLabelImageToStatisticsLabelMapFilterPython.itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3_swigregister(itkLabelImageToStatisticsLabelMapFilterIUC3IUC3LM3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def label_image_to_statistics_label_map_filter(*args: itkt.ImageLike,  background_value: int=..., compute_feret_diameter: bool=..., compute_perimeter: bool=..., feature_image: itkt.Image=..., compute_histogram: bool=..., number_of_bins: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for LabelImageToStatisticsLabelMapFilter"""
    import itk

    kwarg_typehints = { 'background_value':background_value,'compute_feret_diameter':compute_feret_diameter,'compute_perimeter':compute_perimeter,'feature_image':feature_image,'compute_histogram':compute_histogram,'number_of_bins':number_of_bins }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.LabelImageToStatisticsLabelMapFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def label_image_to_statistics_label_map_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKLabelMap.LabelImageToStatisticsLabelMapFilter
    label_image_to_statistics_label_map_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    label_image_to_statistics_label_map_filter.__doc__ = filter_object.__doc__



